from sys import stderr

from click import group
from click import version_option
from loguru import logger

from pd.config.config import config
from pd.conv.conv import conv
from pd.down.down import down
from pd.aws.aws import aws
from pd.edit.edit import edit
from pd.env.env import env
from pd.init.init import init
from pd.nginx.nginx import nginx
from pd.web.web import web
from pd.gen.gen import gen
from pd.version import __version__


@group()
@version_option(__version__, '-v', '--version', help='Show the version and exit')
def cli():
    pass


cli.add_command(config)
cli.add_command(conv)
cli.add_command(down)
cli.add_command(aws)
cli.add_command(edit)
cli.add_command(env)
cli.add_command(gen)
cli.add_command(init)
cli.add_command(nginx)
cli.add_command(web)


def main():
    logger.remove(0)
    logger.add(stderr, level="DEBUG")
    cli()


if __name__ == "__main__":
    main()



import json
import os
from os import path as os_path
from typing import Tuple

from click import Path, argument, group, option
from loguru import logger
from openai import OpenAI
from tqdm import tqdm

from pd.__model__.utils import parse_str_list_str

api_key = os.getenv("PD_OPENAI_API_KEY")
if not api_key:
    logger.info("PD_OPENAI_API_KEY is not set, using default API key")
    api_key = os.getenv("OPENAI_API_KEY")

client = OpenAI(api_key=api_key)


@group(name="gen", help="Generate embeddings for files")
def gen():
    pass


@gen.command(help="Generate embeddings for files")
@option("--model", default="text-embedding-3-small", help="Model to use for embedding")
@option("--keys", callback=parse_str_list_str, type=str, help="Comma separated list of keys to use for embedding")
@argument("filepaths", nargs=-1, type=Path(exists=True), required=True)
def embeddings(filepaths: Tuple[str, ...], model: str, keys: list[str]):
    data: dict[str, str] = {}
    for path in filepaths:
        path_splits = path.split("/")
        filedir = "/".join(path_splits[:-1])

        filename, fileext = os_path.splitext(path_splits[-1])

        if not fileext == ".json":
            raise ValueError(f"File {filename} is not a JSON file")

        logger.debug(f"Path = {path}, filename = {filename}, fileext = {fileext}")

        with open(path, "r") as f:
            filedata = json.load(f)

            if not keys:
                data[filename] = json.dumps(filedata)
            else:
                keyed_data: dict[str, str] = {}
                for key in keys:
                    if key in filedata:
                        keyed_data[key] = filedata[key]

                data[filename] = json.dumps(keyed_data)

    keys = list(data.keys())
    response = client.embeddings.create(input=list(data.values()), model=model)
    if not response.data:
        raise ValueError(f"No embeddings returned for {keys}")

    logger.info(f"Response: {response.data}")

    for i, embedding in tqdm(list(enumerate(response.data))):
        with open(f"{filedir}/{keys[i]}.ebd", "w") as f:
            json.dump(embedding.embedding, f)
